==> nifi-minifi-cpp-0.14.0-source.tar.gz: nifi-minifi-cpp-0.14.0-source/docker/test/integration/cluster/containers/SyslogTcpClientContainer.py <==
# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import logging
from .Container import Container


class SyslogTcpClientContainer(Container):
    def __init__(self, name, vols, network, image_store, command=None):
        super().__init__(name, 'syslog-tcp-client', vols, network, image_store, command)

    def get_startup_finished_log_entry(self):
        return "Syslog TCP client started"

    def deploy(self):
        if not self.set_deployed():
            return

        logging.info('Creating and running a Syslog tcp client docker container...')
        self.client.containers.run(
            "ubuntu:20.04",
            detach=True,
            name=self.name,
            network=self.network.name,
            entrypoint='/bin/bash -c "echo Syslog TCP client started; while true; do logger --tcp -n minifi-cpp-flow -P 514 sample_log; sleep 1; done"')
        logging.info('Added container \'%s\'', self.name)

==> nifi-minifi-cpp-0.99.0-source.tar.gz: nifi-minifi-cpp-0.99.0-source/docker/test/integration/cluster/containers/SyslogTcpClientContainer.py <==
# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import logging
from .Container import Container


class SyslogTcpClientContainer(Container):
    def __init__(self, feature_context, name, vols, network, image_store, command=None):
        super().__init__(feature_context, name, 'syslog-tcp-client', vols, network, image_store, command)

    def get_startup_finished_log_entry(self):
        return "Syslog TCP client started"

    def deploy(self):
        if not self.set_deployed():
            return

        logging.info('Creating and running a Syslog tcp client docker container...')
        self.client.containers.run(
            "ubuntu:20.04",
            detach=True,
            name=self.name,
            network=self.network.name,
            entrypoint='/bin/bash -c "echo Syslog TCP client started; while true; do logger --tcp -n '
                       f'minifi-cpp-flow-{self.feature_context.id} -P 514 sample_log; sleep 1; done"')
        logging.info('Added container \'%s\'', self.name)
